cosmpy.protos.cosmos.staking.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.staking.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.staking.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.staking.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.staking.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.staking.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.staking.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service.

  static Delegation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegatorDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegatorUnbondingDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegatorValidator(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DelegatorValidators(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static HistoricalInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Pool(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Redelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static UnbondingDelegation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Validator(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ValidatorDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ValidatorUnbondingDelegations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Validators(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.staking.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service.

  Delegation(request, context)

    Delegation queries delegate info for given validator delegator pair.

  DelegatorDelegations(request, context)

    DelegatorDelegations queries all delegations of a given delegator address.

  DelegatorUnbondingDelegations(request, context)

    DelegatorUnbondingDelegations queries all unbonding delegations of a given delegator address.

  DelegatorValidator(request, context)

    DelegatorValidator queries validator info for given delegator validator pair.

  DelegatorValidators(request, context)

    DelegatorValidators queries all validators info for given delegator address.

  HistoricalInfo(request, context)

    HistoricalInfo queries the historical info for given height.

  Params(request, context)

    Parameters queries the staking parameters.

  Pool(request, context)

    Pool queries the pool info.

  Redelegations(request, context)

    Redelegations queries redelegations of given address.

  UnbondingDelegation(request, context)

    UnbondingDelegation queries unbonding info for given validator delegator pair.

  Validator(request, context)

    Validator queries validator info for given validator address.

  ValidatorDelegations(request, context)

    ValidatorDelegations queries delegate info for given validator.

  ValidatorUnbondingDelegations(request, context)

    ValidatorUnbondingDelegations queries unbonding delegations of a validator.

  Validators(request, context)

    Validators queries all validators that match the given status.

class cosmpy.protos.cosmos.staking.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service.

cosmpy.protos.cosmos.staking.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.staking.v1beta1.staking_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.staking.v1beta1.staking_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.staking.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.staking.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.staking.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the staking Msg service.

  static BeginRedelegate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static CreateValidator(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Delegate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static EditValidator(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Undelegate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.staking.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the staking Msg service.

  BeginRedelegate(request, context)

    BeginRedelegate defines a method for performing a redelegation of coins from a delegator and source validator to a destination validator.

  CreateValidator(request, context)

    CreateValidator defines a method for creating a new validator.

  Delegate(request, context)

    Delegate defines a method for performing a delegation of coins from a delegator to a validator.

  EditValidator(request, context)

    EditValidator defines a method for editing an existing validator.

  Undelegate(request, context)

    Undelegate defines a method for performing an undelegation from a delegate and a validator.

class cosmpy.protos.cosmos.staking.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the staking Msg service.

cosmpy.protos.cosmos.staking.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents